#!/bin/bash

# Helper file to do the tape change. It allows several methods based on the 
# $TAPE_CHANGE_MODE environment var (got from tar calling environment).
# 
# log -- Logs a line to the log file, requesting the creation of a certain file
#        once created, continues
# 
# interactive - (default) - Asks to change it by hand and press ENTER
# automatic - Calls the rotatemedia file helper from tuxumbackup.device.tape,
#             that should make the robot go to the next tape.


. ${BACKUP_LIB_DIR:-/usr/lib/tuxum-backup}/tuxumbackup.functions

if [ ! "$TAR_FD" ]; then
	echo "This script must be called by tar with the --new-volume-script=$0"
	exit 1
fi

log_info "Tape change: $TAR_ARCHIVE / $TAR_VOLUME"

case "${tape_change_mode:-interactive}" in
"log")
	WAITFILE="/tmp/tb-ready.$$"
	log_info ${LOG} "No more space on tape. Volume full. Change and create file \'$WAITFILE\'."
	while [ ! -e $WAITFILE ]; do
		sleep 1
	done
	rm $WAITFILE
	;;
"interactive")
	echo "Change volume and press ENTER"
	read ignoreme
	;;
"automatic")
	. ${BACKUP_LIB_DIR:-/usr/lib/tuxum-backup}/tuxumbackup.device.tape
	rotatemedia
	;;
"error")
	. ${BACKUP_LIB_DIR:-/usr/lib/tuxum-backup}/tuxumbackup.device.tape
	log_error "No more space on tape. Volume full. Aborting."
	exit 1
	;;
esac

exit 0
